==> sghi_core-0.2.12.tar.gz: lib/afya_moja_core/src/presentation/search_widget.dart <==
// Flutter imports
import 'package:flutter/material.dart';
// Package imports
import 'package:flutter_svg/flutter_svg.dart';
import 'package:sghi_core/afya_moja_core/src/app_asset_strings.dart';
// Project imports
import 'package:sghi_core/afya_moja_core/src/app_strings.dart';

class SearchWidget extends StatelessWidget {
  const SearchWidget({
    super.key,
    required this.onTap,
  });

  final VoidCallback onTap;

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: onTap,
      child: Container(
        width: MediaQuery.of(context).size.width,
        height: 45,
        padding: const EdgeInsets.symmetric(vertical: 10, horizontal: 10),
        decoration: BoxDecoration(
          color: Colors.white,
          borderRadius: BorderRadius.circular(6),
          border: Border.all(
            color: Colors.white.withOpacity(0.3),
          ),
        ),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: <Widget>[
            Flexible(
              child: Text(
                searchUser,
                maxLines: 1,
                overflow: TextOverflow.ellipsis,
                style: Theme.of(context).textTheme.headline4!.copyWith(
                      color: Colors.grey,
                      fontSize: 14,
                    ),
              ),
            ),
            SvgPicture.asset(
              magnifierToolIconSvg,
            ),
          ],
        ),
      ),
    );
  }
}

==> sghi_core-0.3.56.tar.gz: lib/afya_moja_core/src/presentation/search_widget.dart <==
// Flutter imports
import 'package:flutter/material.dart';
// Package imports
import 'package:flutter_svg/flutter_svg.dart';
import 'package:sghi_core/afya_moja_core/src/app_asset_strings.dart';
// Project imports
import 'package:sghi_core/afya_moja_core/src/app_strings.dart';

class SearchWidget extends StatelessWidget {
  const SearchWidget({
    super.key,
    required this.onTap,
  });

  final VoidCallback onTap;

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: onTap,
      child: Container(
        width: MediaQuery.of(context).size.width,
        height: 45,
        padding: const EdgeInsets.symmetric(vertical: 10, horizontal: 10),
        decoration: BoxDecoration(
          color: Colors.white,
          borderRadius: BorderRadius.circular(6),
          border: Border.all(
            color: Colors.white.withOpacity(0.3),
          ),
        ),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: <Widget>[
            Flexible(
              child: Text(
                searchUser,
                maxLines: 1,
                overflow: TextOverflow.ellipsis,
                style: Theme.of(context).textTheme.headlineMedium!.copyWith(
                      color: Colors.grey,
                      fontSize: 14,
                    ),
              ),
            ),
            SvgPicture.asset(
              magnifierToolIconSvg,
            ),
          ],
        ),
      ),
    );
  }
}
